@@ -1,5 +1,7 @@
 from .convert import *  # noqa: F401, F403
 from .frame import *  # noqa: F401, F403
+from .observations import *  # noqa: F401, F403
 from .observer import *  # noqa: F401, F403
 from .optimize import *  # noqa: F401, F403
 from .path_finder import *  # noqa: F401, F403
+from .pointing_error import *  # noqa: F401, F403
