@@ -17,11 +17,12 @@ from astropy.coordinates import (
 from astropy.time import Time
 
 from .. import config, get_logger, utils
-from ..parameters.pointing_error import PointingError
-from ..typing import Number, UnitType
+from ..core import disabled
+from ..core.type_aliases import CoordFrameType, DimensionLess, UnitType
 from .frame import parse_frame
+from .pointing_error import PointingError
 
-T = TypeVar("T", Number, u.Quantity)
+T = TypeVar("T", DimensionLess, u.Quantity)
 
 
 class CoordCalculator:
@@ -83,11 +84,10 @@ class CoordCalculator:
         self,
         location: EarthLocation,
         pointing_param_path: Optional[os.PathLike] = None,
-        pointing_model: Optional[str] = None,
         *,
         pressure: Optional[u.Quantity] = None,
         temperature: Optional[u.Quantity] = None,
-        relative_humidity: Optional[Union[Number, u.Quantity]] = None,
+        relative_humidity: Optional[Union[DimensionLess, u.Quantity]] = None,
         obswl: Optional[u.Quantity] = None,
         obsfreq: Optional[u.Quantity] = None,
     ) -> None:
@@ -107,38 +107,27 @@ class CoordCalculator:
             self.obswl = const.c / obsfreq  # type: ignore
 
         if pointing_param_path is not None:
-            self.pointing_error_corrector = PointingError.from_file(
-                pointing_param_path, pointing_model
-            )
+            self.pointing_error_corrector = PointingError.from_file(pointing_param_path)
         else:
             self.logger.warning("Pointing error correction is disabled.")
-            dummy = PointingError("nanten2")
-            dummy.refracted2apparent = lambda az, el: (az, el)  # type: ignore
+            dummy = PointingError()
+            dummy.refracted_to_apparent = lambda az, el: (az, el)
             self.pointing_error_corrector = dummy
 
         diffraction_params = ["pressure", "temperature", "relative_humidity", "obswl"]
-        not_set = list(filter(lambda x: getattr(self, x) is None, diffraction_params))
+        not_set = list(
+            filter(lambda x: getattr(self, x) != getattr(self, x), diffraction_params)
+        )
         if len(not_set) > 0:
             self.logger.warning(
                 f"{not_set} are not given. Diffraction correction is disabled."
             )
 
-    def _get_altaz_frame(self, obstime: Union[Number, Time]) -> AltAz:
+    def _get_altaz_frame(self, obstime: Union[DimensionLess, Time]) -> AltAz:
         obstime = self._convert_obstime(obstime)
-        if self.temperature is not None:
-            self.temperature = self.temperature.to(
-                "deg_C", equivalencies=u.temperature()
-            )
-        return AltAz(
-            obstime=obstime,
-            location=self.location,
-            pressure=self.pressure,
-            temperature=self.temperature,
-            relative_humidity=self.relative_humidity,
-            obswl=self.obswl,
-        )
+        return AltAz(obstime=obstime, **self.altaz_kwargs)
 
-    def _convert_obstime(self, obstime: Union[Number, Time, None]) -> Time:
+    def _convert_obstime(self, obstime: Union[DimensionLess, Time, None]) -> Time:
         if obstime is None:
             obstime = self._auto_schedule_obstime()
         return obstime if isinstance(obstime, Time) else Time(obstime, format="unix")
@@ -153,10 +142,19 @@ class CoordCalculator:
             format="unix",
         )
 
+    def get_body(self, name: str, obstime: T) -> SkyCoord:
+        if not isinstance(obstime, Time):
+            obstime = Time(obstime, format="unix")
+        try:
+            coord = get_body(name, obstime, self.location)
+        except KeyError:
+            coord = SkyCoord.from_name(name, frame="icrs")
+        return np.broadcast_to(coord, obstime.shape)
+
     def get_altaz_by_name(
         self,
         name: str,
-        obstime: Optional[Union[Number, Time]] = None,
+        obstime: Optional[Union[DimensionLess, Time]] = None,
     ) -> Tuple[u.Quantity, u.Quantity, List[float]]:
         """天体名から地平座標 az, el(alt) を取得する
 
@@ -174,15 +172,10 @@ class CoordCalculator:
 
         """
         obstime = self._convert_obstime(obstime)
-        try:
-            coord = get_body(name, obstime)
-        except KeyError:
-            coord = SkyCoord.from_name(name)
+        coord = self.get_body(name, obstime)
         altaz = coord.transform_to(self._get_altaz_frame(obstime))
         return (
-            *self.pointing_error_corrector.refracted2apparent(
-                altaz.az, altaz.alt  # type: ignore
-            ),
+            *self.pointing_error_corrector.refracted_to_apparent(altaz.az, altaz.alt),
             obstime.unix,
         )
 
@@ -193,7 +186,7 @@ class CoordCalculator:
         frame: Union[str, BaseCoordinateFrame],  # 変換前の座標系
         *,
         unit: Optional[UnitType] = None,
-        obstime: Optional[Union[Number, Time]] = None,
+        obstime: Optional[Union[DimensionLess, Time]] = None,
     ) -> Tuple[u.Quantity, u.Quantity, List[float]]:
         """Get horizontal coordinate from longitude and latitude in arbitrary frame.
 
@@ -224,7 +217,7 @@ class CoordCalculator:
             (
                 apparent_az,
                 apparent_alt,
-            ) = self.pointing_error_corrector.refracted2apparent(lon, lat)
+            ) = self.pointing_error_corrector.refracted_to_apparent(lon, lat)
             return (
                 np.broadcast_to(apparent_az, obstime.shape) << apparent_az.unit,
                 np.broadcast_to(apparent_alt, obstime.shape) << apparent_alt.unit,
@@ -237,8 +230,87 @@ class CoordCalculator:
             self._get_altaz_frame(obstime)
         )
         return (
-            *self.pointing_error_corrector.refracted2apparent(
-                altaz.az, altaz.alt  # type: ignore
-            ),
+            *self.pointing_error_corrector.refracted_to_apparent(altaz.az, altaz.alt),
             obstime.unix,
         )
+
+    @staticmethod
+    def get_position_angle(a: Tuple[T, T], b: Tuple[T, T], /) -> u.Quantity:
+        if a[0] == b[0]:
+            position_angle = (np.pi / 2 * u.rad) * np.sign(b[1] - a[1])
+        else:
+            position_angle = np.arctan((b[1] - a[1]) / (b[0] - a[0])) << u.rad
+            position_angle += (np.pi if b[0] < a[0] else 0) * u.rad
+        return position_angle
+
+    @classmethod
+    def get_extended(
+        cls,
+        a: Tuple[T, T],
+        b: Tuple[T, T],
+        /,
+        *,
+        length: T,
+    ) -> Tuple[T, T]:
+        pa = cls.get_position_angle(a, b)
+        d_lon, d_lat = length * np.cos(pa), length * np.sin(pa)
+        return a[0] - d_lon, a[1] - d_lat
+
+    @property
+    def altaz_kwargs(self) -> dict:
+        return dict(
+            location=self.location,
+            pressure=self.pressure,
+            temperature=self.temperature.to(u.deg_C, equivalencies=u.temperature()),
+            relative_humidity=self.relative_humidity,
+            obswl=self.obswl,
+        )
+
+    def get_skycoord(
+        self,
+        lon: T,
+        lat: T,
+        distance: Optional[T] = None,
+        *,
+        frame: CoordFrameType,
+        obstime: Union[float, List[float]],
+        unit: Optional[UnitType] = None,
+    ) -> SkyCoord:
+        obstime = Time(obstime, format="unix")
+        lon_unit = lon.unit if hasattr(lon, "unit") else 1
+        lat_unit = lat.unit if hasattr(lat, "unit") else 1
+        lon = np.broadcast_to(lon, obstime.shape) * lon_unit
+        lat = np.broadcast_to(lat, obstime.shape) * lat_unit
+        unit = dict(unit=unit) if unit is not None else {}
+        args = [lon, lat]
+        if distance is not None:
+            args.append(distance)
+        if isinstance(frame, str):
+            frame = parse_frame(frame)
+
+        return SkyCoord(
+            *args, frame=frame, obstime=obstime, **self.altaz_kwargs, **unit
+        )
+
+    def transform_to(self, coord: SkyCoord, to: CoordFrameType) -> SkyCoord:
+        if isinstance(to, str):
+            to = parse_frame(to)
+        return coord.transform_to(to)
+
+    @disabled
+    def sidereal_offset(
+        self,
+        reference: Tuple[T, T, CoordFrameType],
+        offset: Tuple[T, T, CoordFrameType],
+        t: List[float],
+        unit: UnitType,
+    ) -> Tuple[T, T]:
+        obstime = Time(t, format="unix")
+        ref = self.get_skycoord(
+            *reference[:2], frame=reference[2], obstime=obstime, unit=unit
+        )
+        ref_in_offset_frame = self.transform_to(ref, offset[2])
+        return (
+            ref_in_offset_frame.data.lon.to_value(unit) + offset[0],
+            ref_in_offset_frame.data.lat.to_value(unit) + offset[1],
+        )
