@@ -2,6 +2,7 @@ import astropy.units as u
 import ogameasure
 
 from ... import utils
+from ...core import logic
 from .attenuator_base import Attenuator
 
 
@@ -18,16 +19,18 @@ class RHIO10(Attenuator):
         self.io = ogameasure.SENA.adios(com)
 
     def get_loss(self, id: str) -> u.Quantity:
-        ch = self.Config.channel[id]
-        if ch == 1:
-            return self.io.get_att1() << u.dB
-        elif ch == 2:
-            return self.io.get_att2() << u.dB
-        raise ValueError(f"Invalid channel: {ch}")
+        with logic.busy(self, "busy"):
+            ch = self.Config.channel[id]
+            if ch == 1:
+                return self.io.get_att1() << u.dB
+            elif ch == 2:
+                return self.io.get_att2() << u.dB
+            raise ValueError(f"Invalid channel: {ch}")
 
     def set_loss(self, dB: int, id: str) -> None:
-        ch = self.Config.channel[id]
-        self.io._set_att(ch, int(dB))
+        with logic.busy(self, "busy"):
+            ch = self.Config.channel[id]
+            self.io._set_att(ch, int(dB))
 
     def finalize(self) -> None:
         self.io.com.close()
