@@ -1,6 +1,7 @@
 from typing import Callable, Union
 
-from ...utils import busy, sanity_check
+from ...core import logic
+from ...utils import sanity_check
 from .da_converter_base import DAConverter
 
 
@@ -33,7 +34,7 @@ class CPZ340816(DAConverter):
             self.param_buff[ch] = self.converter(mV)
 
     def apply_voltage(self) -> None:
-        with busy(self, "busy"):
+        with logic.busy(self, "busy"):
             for i in range(0, 16):
                 ch = int(list(self.param_buff.keys())[i])
                 voltage = list(self.param_buff.values())[i]
