@@ -4,6 +4,7 @@ import astropy.units as u
 import ogameasure
 
 from ... import utils
+from ...core import logic
 from .encoder_base import Encoder
 
 
@@ -20,7 +21,8 @@ class ND287(Encoder):
         self.io = ogameasure.HEIDENHAIN.ND287(self.Config.port)
 
     def get_reading(self) -> u.Quantity:
-        raw = self.io.output_position_display_value()
+        with logic.busy(self, "busy"):
+            raw = self.io.output_position_display_value()
         return float(raw.strip(b"\x02\x00\r\n").decode()) << u.deg  # type: ignore
 
     def finalize(self) -> None:
