@@ -1,7 +1,8 @@
 import astropy.units as u
 import ogameasure
 
-from ... import get_logger, utils
+from ... import get_logger
+from ...core import logic
 from .power_meter_base import PowerMeter
 
 
@@ -18,13 +19,13 @@ class MA24126A(PowerMeter):
         self.io.start()
 
     def get_power(self) -> u.Quantity:
-        with utils.busy(self, "busy"):
+        with logic.busy(self, "busy"):
             ret = self.io.power()
             power = float(ret.decode().split("\n")[0])
             return power * u.mW
 
     def zero_set(self) -> None:
-        with utils.busy(self, "busy"):
+        with logic.busy(self, "busy"):
             self.logger.info("##### usb power meter is doing zero setting now ####")
             self.io.zero_set()
             self.logger.info("##### usb power meter finished zero setting  ####")
