@@ -9,7 +9,8 @@ import astropy.units as u
 import numpy as np
 
 from .. import utils
-from ..typing import AngleUnit
+from ..core import logic
+from ..core.type_aliases import AngleUnit
 from ..utils import AzElData, ParameterList
 
 # Indices for parameter lists.
@@ -178,8 +179,8 @@ class AntennaEncoderEmulator:
             - sped_over.el * accel0_duration.el / 2,
         )
 
-        self.speed.az = utils.clip(_speed.az, absmax=self.cmd_speed.az)
-        self.speed.el = utils.clip(_speed.el, absmax=self.cmd_speed.el)
+        self.speed.az = logic.clip(_speed.az, absmax=self.cmd_speed.az)
+        self.speed.el = logic.clip(_speed.el, absmax=self.cmd_speed.el)
         self.position.az = next_position.az
         self.position.el = next_position.el
 
